# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Protection.PlayReady")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.core
except ImportError:
    pass

try:
    import winsdk.windows.media.protection
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

class NDCertificateFeature(enum.IntEnum):
    TRANSMITTER = 1
    RECEIVER = 2
    SHARED_CERTIFICATE = 3
    SECURE_CLOCK = 4
    ANTI_ROLL_BACK_CLOCK = 5
    C_R_L_S = 9
    PLAY_READY3_FEATURES = 13

class NDCertificatePlatformID(enum.IntEnum):
    WINDOWS = 0
    O_S_X = 1
    WINDOWS_ON_A_R_M = 2
    WINDOWS_MOBILE7 = 5
    I_O_S_ON_A_R_M = 6
    X_BOX_ON_P_P_C = 7
    WINDOWS_PHONE8_ON_A_R_M = 8
    WINDOWS_PHONE8_ON_X86 = 9
    XBOX_ONE = 10
    ANDROID_ON_A_R_M = 11
    WINDOWS_PHONE81_ON_A_R_M = 12
    WINDOWS_PHONE81_ON_X86 = 13

class NDCertificateType(enum.IntEnum):
    UNKNOWN = 0
    P_C = 1
    DEVICE = 2
    DOMAIN = 3
    ISSUER = 4
    CRL_SIGNER = 5
    SERVICE = 6
    SILVERLIGHT = 7
    APPLICATION = 8
    METERING = 9
    KEY_FILE_SIGNER = 10
    SERVER = 11
    LICENSE_SIGNER = 12

class NDClosedCaptionFormat(enum.IntEnum):
    A_T_S_C = 0
    S_C_T_E20 = 1
    UNKNOWN = 2

class NDContentIDType(enum.IntEnum):
    KEY_I_D = 1
    PLAY_READY_OBJECT = 2
    CUSTOM = 3

class NDMediaStreamType(enum.IntEnum):
    AUDIO = 1
    VIDEO = 2

class NDProximityDetectionType(enum.IntEnum):
    U_D_P = 1
    T_C_P = 2
    TRANSPORT_AGNOSTIC = 4

class NDStartAsyncOptions(enum.IntEnum):
    MUTUAL_AUTHENTICATION = 1
    WAIT_FOR_LICENSE_DESCRIPTOR = 2

class PlayReadyDecryptorSetup(enum.IntEnum):
    UNINITIALIZED = 0
    ON_DEMAND = 1

class PlayReadyEncryptionAlgorithm(enum.IntEnum):
    UNPROTECTED = 0
    AES128_CTR = 1
    COCKTAIL = 4
    AES128_CBC = 5
    UNSPECIFIED = 65535
    UNINITIALIZED = 2147483647

class PlayReadyHardwareDRMFeatures(enum.IntEnum):
    HARDWARE_D_R_M = 1
    H_E_V_C = 2
    AES128_CBC = 3

class PlayReadyITADataFormat(enum.IntEnum):
    SERIALIZED_PROPERTIES = 0
    SERIALIZED_PROPERTIES_WITH_CONTENT_PROTECTION_WRAPPER = 1

_ns_module._register_NDCertificateFeature(NDCertificateFeature)
_ns_module._register_NDCertificatePlatformID(NDCertificatePlatformID)
_ns_module._register_NDCertificateType(NDCertificateType)
_ns_module._register_NDClosedCaptionFormat(NDClosedCaptionFormat)
_ns_module._register_NDContentIDType(NDContentIDType)
_ns_module._register_NDMediaStreamType(NDMediaStreamType)
_ns_module._register_NDProximityDetectionType(NDProximityDetectionType)
_ns_module._register_NDStartAsyncOptions(NDStartAsyncOptions)
_ns_module._register_PlayReadyDecryptorSetup(PlayReadyDecryptorSetup)
_ns_module._register_PlayReadyEncryptionAlgorithm(PlayReadyEncryptionAlgorithm)
_ns_module._register_PlayReadyHardwareDRMFeatures(PlayReadyHardwareDRMFeatures)
_ns_module._register_PlayReadyITADataFormat(PlayReadyITADataFormat)

NDClient = _ns_module.NDClient
NDCustomData = _ns_module.NDCustomData
NDDownloadEngineNotifier = _ns_module.NDDownloadEngineNotifier
NDLicenseFetchDescriptor = _ns_module.NDLicenseFetchDescriptor
NDStorageFileHelper = _ns_module.NDStorageFileHelper
NDStreamParserNotifier = _ns_module.NDStreamParserNotifier
NDTCPMessenger = _ns_module.NDTCPMessenger
PlayReadyContentHeader = _ns_module.PlayReadyContentHeader
PlayReadyContentResolver = _ns_module.PlayReadyContentResolver
PlayReadyDomain = _ns_module.PlayReadyDomain
PlayReadyDomainIterable = _ns_module.PlayReadyDomainIterable
PlayReadyDomainIterator = _ns_module.PlayReadyDomainIterator
PlayReadyDomainJoinServiceRequest = _ns_module.PlayReadyDomainJoinServiceRequest
PlayReadyDomainLeaveServiceRequest = _ns_module.PlayReadyDomainLeaveServiceRequest
PlayReadyITADataGenerator = _ns_module.PlayReadyITADataGenerator
PlayReadyIndividualizationServiceRequest = _ns_module.PlayReadyIndividualizationServiceRequest
PlayReadyLicense = _ns_module.PlayReadyLicense
PlayReadyLicenseAcquisitionServiceRequest = _ns_module.PlayReadyLicenseAcquisitionServiceRequest
PlayReadyLicenseIterable = _ns_module.PlayReadyLicenseIterable
PlayReadyLicenseIterator = _ns_module.PlayReadyLicenseIterator
PlayReadyLicenseManagement = _ns_module.PlayReadyLicenseManagement
PlayReadyLicenseSession = _ns_module.PlayReadyLicenseSession
PlayReadyMeteringReportServiceRequest = _ns_module.PlayReadyMeteringReportServiceRequest
PlayReadyRevocationServiceRequest = _ns_module.PlayReadyRevocationServiceRequest
PlayReadySecureStopIterable = _ns_module.PlayReadySecureStopIterable
PlayReadySecureStopIterator = _ns_module.PlayReadySecureStopIterator
PlayReadySecureStopServiceRequest = _ns_module.PlayReadySecureStopServiceRequest
PlayReadySoapMessage = _ns_module.PlayReadySoapMessage
PlayReadyStatics = _ns_module.PlayReadyStatics
INDClosedCaptionDataReceivedEventArgs = _ns_module.INDClosedCaptionDataReceivedEventArgs
INDCustomData = _ns_module.INDCustomData
INDDownloadEngine = _ns_module.INDDownloadEngine
INDDownloadEngineNotifier = _ns_module.INDDownloadEngineNotifier
INDLicenseFetchCompletedEventArgs = _ns_module.INDLicenseFetchCompletedEventArgs
INDLicenseFetchDescriptor = _ns_module.INDLicenseFetchDescriptor
INDLicenseFetchResult = _ns_module.INDLicenseFetchResult
INDMessenger = _ns_module.INDMessenger
INDProximityDetectionCompletedEventArgs = _ns_module.INDProximityDetectionCompletedEventArgs
INDRegistrationCompletedEventArgs = _ns_module.INDRegistrationCompletedEventArgs
INDSendResult = _ns_module.INDSendResult
INDStartResult = _ns_module.INDStartResult
INDStorageFileHelper = _ns_module.INDStorageFileHelper
INDStreamParser = _ns_module.INDStreamParser
INDStreamParserNotifier = _ns_module.INDStreamParserNotifier
INDTransmitterProperties = _ns_module.INDTransmitterProperties
IPlayReadyDomain = _ns_module.IPlayReadyDomain
IPlayReadyLicense = _ns_module.IPlayReadyLicense
IPlayReadyLicenseAcquisitionServiceRequest = _ns_module.IPlayReadyLicenseAcquisitionServiceRequest
IPlayReadyLicenseSession = _ns_module.IPlayReadyLicenseSession
IPlayReadyLicenseSession2 = _ns_module.IPlayReadyLicenseSession2
IPlayReadySecureStopServiceRequest = _ns_module.IPlayReadySecureStopServiceRequest
IPlayReadyServiceRequest = _ns_module.IPlayReadyServiceRequest



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Input")

try:
    import winsdk.windows.devices.haptics
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class PointerDeviceType(enum.IntEnum):
    TOUCH = 0
    PEN = 1
    MOUSE = 2

_ns_module._register_PointerDeviceType(PointerDeviceType)

MouseDelta = _ns_module.MouseDelta
PointerDeviceUsage = _ns_module.PointerDeviceUsage
KeyboardCapabilities = _ns_module.KeyboardCapabilities
MouseCapabilities = _ns_module.MouseCapabilities
MouseDevice = _ns_module.MouseDevice
MouseEventArgs = _ns_module.MouseEventArgs
PenButtonListener = _ns_module.PenButtonListener
PenDevice = _ns_module.PenDevice
PenDockListener = _ns_module.PenDockListener
PenDockedEventArgs = _ns_module.PenDockedEventArgs
PenTailButtonClickedEventArgs = _ns_module.PenTailButtonClickedEventArgs
PenTailButtonDoubleClickedEventArgs = _ns_module.PenTailButtonDoubleClickedEventArgs
PenTailButtonLongPressedEventArgs = _ns_module.PenTailButtonLongPressedEventArgs
PenUndockedEventArgs = _ns_module.PenUndockedEventArgs
PointerDevice = _ns_module.PointerDevice
TouchCapabilities = _ns_module.TouchCapabilities



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.Power.Diagnostics")


BackgroundEnergyDiagnostics = _ns_module.BackgroundEnergyDiagnostics
ForegroundEnergyDiagnostics = _ns_module.ForegroundEnergyDiagnostics



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system

Self = typing.TypeVar('Self')

class RemoteTextConnection(winsdk.system.Object):
    is_enabled: winsdk.system.Boolean
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> RemoteTextConnection: ...
    def __new__(cls: typing.Type[RemoteTextConnection], connection_id: winsdk.system.Guid, pdu_forwarder: typing.Optional[RemoteTextConnectionDataHandler]) -> RemoteTextConnection:...
    def close(self) -> None: ...
    def register_thread(self, thread_id: winsdk.system.UInt32) -> None: ...
    def report_data_received(self, pdu_data: winsdk.system.Array[winsdk.system.UInt8]) -> None: ...
    def unregister_thread(self, thread_id: winsdk.system.UInt32) -> None: ...

RemoteTextConnectionDataHandler = typing.Callable[[winsdk.system.Array[winsdk.system.UInt8]], winsdk.system.Boolean]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Capture.Frames")

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.graphics.directx.direct3d11
except ImportError:
    pass

try:
    import winsdk.windows.graphics.imaging
except ImportError:
    pass

try:
    import winsdk.windows.media
except ImportError:
    pass

try:
    import winsdk.windows.media.capture
except ImportError:
    pass

try:
    import winsdk.windows.media.devices
except ImportError:
    pass

try:
    import winsdk.windows.media.devices.core
except ImportError:
    pass

try:
    import winsdk.windows.media.mediaproperties
except ImportError:
    pass

try:
    import winsdk.windows.perception.spatial
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.ui.windowmanagement
except ImportError:
    pass

class MediaFrameReaderAcquisitionMode(enum.IntEnum):
    REALTIME = 0
    BUFFERED = 1

class MediaFrameReaderStartStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    DEVICE_NOT_AVAILABLE = 2
    OUTPUT_FORMAT_NOT_SUPPORTED = 3
    EXCLUSIVE_CONTROL_NOT_AVAILABLE = 4

class MediaFrameSourceGetPropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    DEVICE_NOT_AVAILABLE = 3
    MAX_PROPERTY_VALUE_SIZE_TOO_SMALL = 4
    MAX_PROPERTY_VALUE_SIZE_REQUIRED = 5

class MediaFrameSourceKind(enum.IntEnum):
    CUSTOM = 0
    COLOR = 1
    INFRARED = 2
    DEPTH = 3
    AUDIO = 4
    IMAGE = 5
    METADATA = 6

class MediaFrameSourceSetPropertyStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_FAILURE = 1
    NOT_SUPPORTED = 2
    INVALID_VALUE = 3
    DEVICE_NOT_AVAILABLE = 4
    NOT_IN_CONTROL = 5

class MultiSourceMediaFrameReaderStartStatus(enum.IntEnum):
    SUCCESS = 0
    NOT_SUPPORTED = 1
    INSUFFICIENT_RESOURCES = 2
    DEVICE_NOT_AVAILABLE = 3
    UNKNOWN_FAILURE = 4

_ns_module._register_MediaFrameReaderAcquisitionMode(MediaFrameReaderAcquisitionMode)
_ns_module._register_MediaFrameReaderStartStatus(MediaFrameReaderStartStatus)
_ns_module._register_MediaFrameSourceGetPropertyStatus(MediaFrameSourceGetPropertyStatus)
_ns_module._register_MediaFrameSourceKind(MediaFrameSourceKind)
_ns_module._register_MediaFrameSourceSetPropertyStatus(MediaFrameSourceSetPropertyStatus)
_ns_module._register_MultiSourceMediaFrameReaderStartStatus(MultiSourceMediaFrameReaderStartStatus)

AudioMediaFrame = _ns_module.AudioMediaFrame
BufferMediaFrame = _ns_module.BufferMediaFrame
DepthMediaFrame = _ns_module.DepthMediaFrame
DepthMediaFrameFormat = _ns_module.DepthMediaFrameFormat
InfraredMediaFrame = _ns_module.InfraredMediaFrame
MediaFrameArrivedEventArgs = _ns_module.MediaFrameArrivedEventArgs
MediaFrameFormat = _ns_module.MediaFrameFormat
MediaFrameReader = _ns_module.MediaFrameReader
MediaFrameReference = _ns_module.MediaFrameReference
MediaFrameSource = _ns_module.MediaFrameSource
MediaFrameSourceController = _ns_module.MediaFrameSourceController
MediaFrameSourceGetPropertyResult = _ns_module.MediaFrameSourceGetPropertyResult
MediaFrameSourceGroup = _ns_module.MediaFrameSourceGroup
MediaFrameSourceInfo = _ns_module.MediaFrameSourceInfo
MultiSourceMediaFrameArrivedEventArgs = _ns_module.MultiSourceMediaFrameArrivedEventArgs
MultiSourceMediaFrameReader = _ns_module.MultiSourceMediaFrameReader
MultiSourceMediaFrameReference = _ns_module.MultiSourceMediaFrameReference
VideoMediaFrame = _ns_module.VideoMediaFrame
VideoMediaFrameFormat = _ns_module.VideoMediaFrameFormat



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Contacts.DataProvider")

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass


ContactDataProviderConnection = _ns_module.ContactDataProviderConnection
ContactDataProviderTriggerDetails = _ns_module.ContactDataProviderTriggerDetails
ContactListCreateOrUpdateContactRequest = _ns_module.ContactListCreateOrUpdateContactRequest
ContactListCreateOrUpdateContactRequestEventArgs = _ns_module.ContactListCreateOrUpdateContactRequestEventArgs
ContactListDeleteContactRequest = _ns_module.ContactListDeleteContactRequest
ContactListDeleteContactRequestEventArgs = _ns_module.ContactListDeleteContactRequestEventArgs
ContactListServerSearchReadBatchRequest = _ns_module.ContactListServerSearchReadBatchRequest
ContactListServerSearchReadBatchRequestEventArgs = _ns_module.ContactListServerSearchReadBatchRequestEventArgs
ContactListSyncManagerSyncRequest = _ns_module.ContactListSyncManagerSyncRequest
ContactListSyncManagerSyncRequestEventArgs = _ns_module.ContactListSyncManagerSyncRequestEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Protection")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.playback
except ImportError:
    pass

class GraphicsTrustStatus(enum.IntEnum):
    TRUST_NOT_REQUIRED = 0
    TRUST_ESTABLISHED = 1
    ENVIRONMENT_NOT_SUPPORTED = 2
    DRIVER_NOT_SUPPORTED = 3
    DRIVER_SIGNING_FAILURE = 4
    UNKNOWN_FAILURE = 5

class HdcpProtection(enum.IntEnum):
    OFF = 0
    ON = 1
    ON_WITH_TYPE_ENFORCEMENT = 2

class HdcpSetProtectionResult(enum.IntEnum):
    SUCCESS = 0
    TIMED_OUT = 1
    NOT_SUPPORTED = 2
    UNKNOWN_FAILURE = 3

class ProtectionCapabilityResult(enum.IntEnum):
    NOT_SUPPORTED = 0
    MAYBE = 1
    PROBABLY = 2

class RenewalStatus(enum.IntEnum):
    NOT_STARTED = 0
    UPDATES_IN_PROGRESS = 1
    USER_CANCELLED = 2
    APP_COMPONENTS_MAY_NEED_UPDATING = 3
    NO_COMPONENTS_FOUND = 4

class RevocationAndRenewalReasons(enum.IntFlag):
    USER_MODE_COMPONENT_LOAD = 0x1
    KERNEL_MODE_COMPONENT_LOAD = 0x2
    APP_COMPONENT = 0x4
    GLOBAL_REVOCATION_LIST_LOAD_FAILED = 0x10
    INVALID_GLOBAL_REVOCATION_LIST_SIGNATURE = 0x20
    GLOBAL_REVOCATION_LIST_ABSENT = 0x1000
    COMPONENT_REVOKED = 0x2000
    INVALID_COMPONENT_CERTIFICATE_EXTENDED_KEY_USE = 0x4000
    COMPONENT_CERTIFICATE_REVOKED = 0x8000
    INVALID_COMPONENT_CERTIFICATE_ROOT = 0x10000
    COMPONENT_HIGH_SECURITY_CERTIFICATE_REVOKED = 0x20000
    COMPONENT_LOW_SECURITY_CERTIFICATE_REVOKED = 0x40000
    BOOT_DRIVER_VERIFICATION_FAILED = 0x100000
    COMPONENT_SIGNED_WITH_TEST_CERTIFICATE = 0x1000000
    ENCRYPTION_FAILURE = 0x10000000

_ns_module._register_GraphicsTrustStatus(GraphicsTrustStatus)
_ns_module._register_HdcpProtection(HdcpProtection)
_ns_module._register_HdcpSetProtectionResult(HdcpSetProtectionResult)
_ns_module._register_ProtectionCapabilityResult(ProtectionCapabilityResult)
_ns_module._register_RenewalStatus(RenewalStatus)
_ns_module._register_RevocationAndRenewalReasons(RevocationAndRenewalReasons)

ComponentLoadFailedEventArgs = _ns_module.ComponentLoadFailedEventArgs
ComponentRenewal = _ns_module.ComponentRenewal
HdcpSession = _ns_module.HdcpSession
MediaProtectionManager = _ns_module.MediaProtectionManager
MediaProtectionPMPServer = _ns_module.MediaProtectionPMPServer
MediaProtectionServiceCompletion = _ns_module.MediaProtectionServiceCompletion
ProtectionCapabilities = _ns_module.ProtectionCapabilities
RevocationAndRenewalInformation = _ns_module.RevocationAndRenewalInformation
RevocationAndRenewalItem = _ns_module.RevocationAndRenewalItem
ServiceRequestedEventArgs = _ns_module.ServiceRequestedEventArgs
IMediaProtectionServiceRequest = _ns_module.IMediaProtectionServiceRequest



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Core.AnimationMetrics")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class AnimationEffect(enum.IntEnum):
    EXPAND = 0
    COLLAPSE = 1
    REPOSITION = 2
    FADE_IN = 3
    FADE_OUT = 4
    ADD_TO_LIST = 5
    DELETE_FROM_LIST = 6
    ADD_TO_GRID = 7
    DELETE_FROM_GRID = 8
    ADD_TO_SEARCH_GRID = 9
    DELETE_FROM_SEARCH_GRID = 10
    ADD_TO_SEARCH_LIST = 11
    DELETE_FROM_SEARCH_LIST = 12
    SHOW_EDGE_U_I = 13
    SHOW_PANEL = 14
    HIDE_EDGE_U_I = 15
    HIDE_PANEL = 16
    SHOW_POPUP = 17
    HIDE_POPUP = 18
    POINTER_DOWN = 19
    POINTER_UP = 20
    DRAG_SOURCE_START = 21
    DRAG_SOURCE_END = 22
    TRANSITION_CONTENT = 23
    REVEAL = 24
    HIDE = 25
    DRAG_BETWEEN_ENTER = 26
    DRAG_BETWEEN_LEAVE = 27
    SWIPE_SELECT = 28
    SWIPE_DESELECT = 29
    SWIPE_REVEAL = 30
    ENTER_PAGE = 31
    TRANSITION_PAGE = 32
    CROSS_FADE = 33
    PEEK = 34
    UPDATE_BADGE = 35

class AnimationEffectTarget(enum.IntEnum):
    PRIMARY = 0
    ADDED = 1
    AFFECTED = 2
    BACKGROUND = 3
    CONTENT = 4
    DELETED = 5
    DESELECTED = 6
    DRAG_SOURCE = 7
    HIDDEN = 8
    INCOMING = 9
    OUTGOING = 10
    OUTLINE = 11
    REMAINING = 12
    REVEALED = 13
    ROW_IN = 14
    ROW_OUT = 15
    SELECTED = 16
    SELECTION = 17
    SHOWN = 18
    TAPPED = 19

class PropertyAnimationType(enum.IntEnum):
    SCALE = 0
    TRANSLATION = 1
    OPACITY = 2

_ns_module._register_AnimationEffect(AnimationEffect)
_ns_module._register_AnimationEffectTarget(AnimationEffectTarget)
_ns_module._register_PropertyAnimationType(PropertyAnimationType)

AnimationDescription = _ns_module.AnimationDescription
OpacityAnimation = _ns_module.OpacityAnimation
PropertyAnimation = _ns_module.PropertyAnimation
ScaleAnimation = _ns_module.ScaleAnimation
TranslationAnimation = _ns_module.TranslationAnimation
IPropertyAnimation = _ns_module.IPropertyAnimation



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation

Self = typing.TypeVar('Self')

class Battery(winsdk.system.Object):
    remaining_charge_percent: winsdk.system.Int32
    remaining_discharge_time: datetime.timedelta
    @staticmethod
    def _from(obj: winsdk.system.Object) -> Battery: ...
    @staticmethod
    def get_default() -> typing.Optional[Battery]: ...
    def add_remaining_charge_percent_changed(self, change_handler: winsdk.windows.foundation.EventHandler[winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_remaining_charge_percent_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Storage.Streams")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class ByteOrder(enum.IntEnum):
    LITTLE_ENDIAN = 0
    BIG_ENDIAN = 1

class FileOpenDisposition(enum.IntEnum):
    OPEN_EXISTING = 0
    OPEN_ALWAYS = 1
    CREATE_NEW = 2
    CREATE_ALWAYS = 3
    TRUNCATE_EXISTING = 4

class InputStreamOptions(enum.IntFlag):
    NONE = 0
    PARTIAL = 0x1
    READ_AHEAD = 0x2

class UnicodeEncoding(enum.IntEnum):
    UTF8 = 0
    UTF16_L_E = 1
    UTF16_B_E = 2

_ns_module._register_ByteOrder(ByteOrder)
_ns_module._register_FileOpenDisposition(FileOpenDisposition)
_ns_module._register_InputStreamOptions(InputStreamOptions)
_ns_module._register_UnicodeEncoding(UnicodeEncoding)

Buffer = _ns_module.Buffer
DataReader = _ns_module.DataReader
DataReaderLoadOperation = _ns_module.DataReaderLoadOperation
DataWriter = _ns_module.DataWriter
DataWriterStoreOperation = _ns_module.DataWriterStoreOperation
FileInputStream = _ns_module.FileInputStream
FileOutputStream = _ns_module.FileOutputStream
FileRandomAccessStream = _ns_module.FileRandomAccessStream
InMemoryRandomAccessStream = _ns_module.InMemoryRandomAccessStream
InputStreamOverStream = _ns_module.InputStreamOverStream
OutputStreamOverStream = _ns_module.OutputStreamOverStream
RandomAccessStream = _ns_module.RandomAccessStream
RandomAccessStreamOverStream = _ns_module.RandomAccessStreamOverStream
RandomAccessStreamReference = _ns_module.RandomAccessStreamReference
IBuffer = _ns_module.IBuffer
IContentTypeProvider = _ns_module.IContentTypeProvider
IDataReader = _ns_module.IDataReader
IDataWriter = _ns_module.IDataWriter
IInputStream = _ns_module.IInputStream
IInputStreamReference = _ns_module.IInputStreamReference
IOutputStream = _ns_module.IOutputStream
IPropertySetSerializer = _ns_module.IPropertySetSerializer
IRandomAccessStream = _ns_module.IRandomAccessStream
IRandomAccessStreamReference = _ns_module.IRandomAccessStreamReference
IRandomAccessStreamWithContentType = _ns_module.IRandomAccessStreamWithContentType



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Devices.Haptics")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

class VibrationAccessStatus(enum.IntEnum):
    ALLOWED = 0
    DENIED_BY_USER = 1
    DENIED_BY_SYSTEM = 2
    DENIED_BY_ENERGY_SAVER = 3

_ns_module._register_VibrationAccessStatus(VibrationAccessStatus)

KnownSimpleHapticsControllerWaveforms = _ns_module.KnownSimpleHapticsControllerWaveforms
SimpleHapticsController = _ns_module.SimpleHapticsController
SimpleHapticsControllerFeedback = _ns_module.SimpleHapticsControllerFeedback
VibrationDevice = _ns_module.VibrationDevice



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.WebUI")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.activation
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.appointments.appointmentsprovider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.background
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.calls
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.contacts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.core
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.datatransfer.sharetarget
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.search
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.userdataaccounts.provider
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.wallet
except ImportError:
    pass

try:
    import winsdk.windows.devices.enumeration
except ImportError:
    pass

try:
    import winsdk.windows.devices.printers.extensions
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.media.speechrecognition
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web
except ImportError:
    pass

try:
    import winsdk.windows.security.authentication.web.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.pickers.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.provider
except ImportError:
    pass

try:
    import winsdk.windows.storage.search
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui
except ImportError:
    pass

try:
    import winsdk.windows.web
except ImportError:
    pass

try:
    import winsdk.windows.web.http
except ImportError:
    pass

try:
    import winsdk.windows.web.ui
except ImportError:
    pass

class PrintContent(enum.IntEnum):
    ALL_PAGES = 0
    CURRENT_PAGE = 1
    CUSTOM_PAGE_RANGE = 2
    CURRENT_SELECTION = 3

_ns_module._register_PrintContent(PrintContent)

ActivatedDeferral = _ns_module.ActivatedDeferral
ActivatedOperation = _ns_module.ActivatedOperation
BackgroundActivatedEventArgs = _ns_module.BackgroundActivatedEventArgs
EnteredBackgroundEventArgs = _ns_module.EnteredBackgroundEventArgs
HtmlPrintDocumentSource = _ns_module.HtmlPrintDocumentSource
LeavingBackgroundEventArgs = _ns_module.LeavingBackgroundEventArgs
NewWebUIViewCreatedEventArgs = _ns_module.NewWebUIViewCreatedEventArgs
SuspendingDeferral = _ns_module.SuspendingDeferral
SuspendingEventArgs = _ns_module.SuspendingEventArgs
SuspendingOperation = _ns_module.SuspendingOperation
WebUIApplication = _ns_module.WebUIApplication
WebUIAppointmentsProviderAddAppointmentActivatedEventArgs = _ns_module.WebUIAppointmentsProviderAddAppointmentActivatedEventArgs
WebUIAppointmentsProviderRemoveAppointmentActivatedEventArgs = _ns_module.WebUIAppointmentsProviderRemoveAppointmentActivatedEventArgs
WebUIAppointmentsProviderReplaceAppointmentActivatedEventArgs = _ns_module.WebUIAppointmentsProviderReplaceAppointmentActivatedEventArgs
WebUIAppointmentsProviderShowAppointmentDetailsActivatedEventArgs = _ns_module.WebUIAppointmentsProviderShowAppointmentDetailsActivatedEventArgs
WebUIAppointmentsProviderShowTimeFrameActivatedEventArgs = _ns_module.WebUIAppointmentsProviderShowTimeFrameActivatedEventArgs
WebUIBackgroundTaskInstance = _ns_module.WebUIBackgroundTaskInstance
WebUIBackgroundTaskInstanceRuntimeClass = _ns_module.WebUIBackgroundTaskInstanceRuntimeClass
WebUIBarcodeScannerPreviewActivatedEventArgs = _ns_module.WebUIBarcodeScannerPreviewActivatedEventArgs
WebUICachedFileUpdaterActivatedEventArgs = _ns_module.WebUICachedFileUpdaterActivatedEventArgs
WebUICameraSettingsActivatedEventArgs = _ns_module.WebUICameraSettingsActivatedEventArgs
WebUICommandLineActivatedEventArgs = _ns_module.WebUICommandLineActivatedEventArgs
WebUIContactCallActivatedEventArgs = _ns_module.WebUIContactCallActivatedEventArgs
WebUIContactMapActivatedEventArgs = _ns_module.WebUIContactMapActivatedEventArgs
WebUIContactMessageActivatedEventArgs = _ns_module.WebUIContactMessageActivatedEventArgs
WebUIContactPanelActivatedEventArgs = _ns_module.WebUIContactPanelActivatedEventArgs
WebUIContactPickerActivatedEventArgs = _ns_module.WebUIContactPickerActivatedEventArgs
WebUIContactPostActivatedEventArgs = _ns_module.WebUIContactPostActivatedEventArgs
WebUIContactVideoCallActivatedEventArgs = _ns_module.WebUIContactVideoCallActivatedEventArgs
WebUIDeviceActivatedEventArgs = _ns_module.WebUIDeviceActivatedEventArgs
WebUIDevicePairingActivatedEventArgs = _ns_module.WebUIDevicePairingActivatedEventArgs
WebUIDialReceiverActivatedEventArgs = _ns_module.WebUIDialReceiverActivatedEventArgs
WebUIFileActivatedEventArgs = _ns_module.WebUIFileActivatedEventArgs
WebUIFileOpenPickerActivatedEventArgs = _ns_module.WebUIFileOpenPickerActivatedEventArgs
WebUIFileOpenPickerContinuationEventArgs = _ns_module.WebUIFileOpenPickerContinuationEventArgs
WebUIFileSavePickerActivatedEventArgs = _ns_module.WebUIFileSavePickerActivatedEventArgs
WebUIFileSavePickerContinuationEventArgs = _ns_module.WebUIFileSavePickerContinuationEventArgs
WebUIFolderPickerContinuationEventArgs = _ns_module.WebUIFolderPickerContinuationEventArgs
WebUILaunchActivatedEventArgs = _ns_module.WebUILaunchActivatedEventArgs
WebUILockScreenActivatedEventArgs = _ns_module.WebUILockScreenActivatedEventArgs
WebUILockScreenCallActivatedEventArgs = _ns_module.WebUILockScreenCallActivatedEventArgs
WebUILockScreenComponentActivatedEventArgs = _ns_module.WebUILockScreenComponentActivatedEventArgs
WebUINavigatedDeferral = _ns_module.WebUINavigatedDeferral
WebUINavigatedEventArgs = _ns_module.WebUINavigatedEventArgs
WebUINavigatedOperation = _ns_module.WebUINavigatedOperation
WebUIPhoneCallActivatedEventArgs = _ns_module.WebUIPhoneCallActivatedEventArgs
WebUIPrint3DWorkflowActivatedEventArgs = _ns_module.WebUIPrint3DWorkflowActivatedEventArgs
WebUIPrintTaskSettingsActivatedEventArgs = _ns_module.WebUIPrintTaskSettingsActivatedEventArgs
WebUIPrintWorkflowForegroundTaskActivatedEventArgs = _ns_module.WebUIPrintWorkflowForegroundTaskActivatedEventArgs
WebUIProtocolActivatedEventArgs = _ns_module.WebUIProtocolActivatedEventArgs
WebUIProtocolForResultsActivatedEventArgs = _ns_module.WebUIProtocolForResultsActivatedEventArgs
WebUIRestrictedLaunchActivatedEventArgs = _ns_module.WebUIRestrictedLaunchActivatedEventArgs
WebUISearchActivatedEventArgs = _ns_module.WebUISearchActivatedEventArgs
WebUIShareTargetActivatedEventArgs = _ns_module.WebUIShareTargetActivatedEventArgs
WebUIStartupTaskActivatedEventArgs = _ns_module.WebUIStartupTaskActivatedEventArgs
WebUIToastNotificationActivatedEventArgs = _ns_module.WebUIToastNotificationActivatedEventArgs
WebUIUserDataAccountProviderActivatedEventArgs = _ns_module.WebUIUserDataAccountProviderActivatedEventArgs
WebUIView = _ns_module.WebUIView
WebUIVoiceCommandActivatedEventArgs = _ns_module.WebUIVoiceCommandActivatedEventArgs
WebUIWalletActionActivatedEventArgs = _ns_module.WebUIWalletActionActivatedEventArgs
WebUIWebAccountProviderActivatedEventArgs = _ns_module.WebUIWebAccountProviderActivatedEventArgs
WebUIWebAuthenticationBrokerContinuationEventArgs = _ns_module.WebUIWebAuthenticationBrokerContinuationEventArgs
IActivatedEventArgsDeferral = _ns_module.IActivatedEventArgsDeferral
IWebUIBackgroundTaskInstance = _ns_module.IWebUIBackgroundTaskInstance
IWebUINavigatedEventArgs = _ns_module.IWebUINavigatedEventArgs



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.System.UserProfile")

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.globalization
except ImportError:
    pass

try:
    import winsdk.windows.storage
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class AccountPictureKind(enum.IntEnum):
    SMALL_IMAGE = 0
    LARGE_IMAGE = 1
    VIDEO = 2

class SetAccountPictureResult(enum.IntEnum):
    SUCCESS = 0
    CHANGE_DISABLED = 1
    LARGE_OR_DYNAMIC_ERROR = 2
    VIDEO_FRAME_SIZE_ERROR = 3
    FILE_SIZE_ERROR = 4
    FAILURE = 5

class SetImageFeedResult(enum.IntEnum):
    SUCCESS = 0
    CHANGE_DISABLED = 1
    USER_CANCELED = 2

_ns_module._register_AccountPictureKind(AccountPictureKind)
_ns_module._register_SetAccountPictureResult(SetAccountPictureResult)
_ns_module._register_SetImageFeedResult(SetImageFeedResult)

AdvertisingManager = _ns_module.AdvertisingManager
AdvertisingManagerForUser = _ns_module.AdvertisingManagerForUser
AssignedAccessSettings = _ns_module.AssignedAccessSettings
DiagnosticsSettings = _ns_module.DiagnosticsSettings
FirstSignInSettings = _ns_module.FirstSignInSettings
GlobalizationPreferences = _ns_module.GlobalizationPreferences
GlobalizationPreferencesForUser = _ns_module.GlobalizationPreferencesForUser
LockScreen = _ns_module.LockScreen
UserInformation = _ns_module.UserInformation
UserProfilePersonalizationSettings = _ns_module.UserProfilePersonalizationSettings



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.fileproperties
import winsdk.windows.storage.provider
import winsdk.windows.storage.search
import winsdk.windows.storage.streams
import winsdk.windows.system

class ApplicationDataCreateDisposition(enum.IntEnum):
    ALWAYS = 0
    EXISTING = 1

class ApplicationDataLocality(enum.IntEnum):
    LOCAL = 0
    ROAMING = 1
    TEMPORARY = 2
    LOCAL_CACHE = 3
    SHARED_LOCAL = 4

class CreationCollisionOption(enum.IntEnum):
    GENERATE_UNIQUE_NAME = 0
    REPLACE_EXISTING = 1
    FAIL_IF_EXISTS = 2
    OPEN_IF_EXISTS = 3

class FileAccessMode(enum.IntEnum):
    READ = 0
    READ_WRITE = 1

class FileAttributes(enum.IntFlag):
    NORMAL = 0
    READ_ONLY = 0x1
    DIRECTORY = 0x10
    ARCHIVE = 0x20
    TEMPORARY = 0x100
    LOCALLY_INCOMPLETE = 0x200

class KnownFolderId(enum.IntEnum):
    APP_CAPTURES = 0
    CAMERA_ROLL = 1
    DOCUMENTS_LIBRARY = 2
    HOME_GROUP = 3
    MEDIA_SERVER_DEVICES = 4
    MUSIC_LIBRARY = 5
    OBJECTS3_D = 6
    PICTURES_LIBRARY = 7
    PLAYLISTS = 8
    RECORDED_CALLS = 9
    REMOVABLE_DEVICES = 10
    SAVED_PICTURES = 11
    SCREENSHOTS = 12
    VIDEOS_LIBRARY = 13
    ALL_APP_MODS = 14
    CURRENT_APP_MODS = 15
    DOWNLOADS_FOLDER = 16

class KnownFoldersAccessStatus(enum.IntEnum):
    DENIED_BY_SYSTEM = 0
    NOT_DECLARED_BY_APP = 1
    DENIED_BY_USER = 2
    USER_PROMPT_REQUIRED = 3
    ALLOWED = 4
    ALLOWED_PER_APP_FOLDER = 5

class KnownLibraryId(enum.IntEnum):
    MUSIC = 0
    PICTURES = 1
    VIDEOS = 2
    DOCUMENTS = 3

class NameCollisionOption(enum.IntEnum):
    GENERATE_UNIQUE_NAME = 0
    REPLACE_EXISTING = 1
    FAIL_IF_EXISTS = 2

class StorageDeleteOption(enum.IntEnum):
    DEFAULT = 0
    PERMANENT_DELETE = 1

class StorageItemTypes(enum.IntFlag):
    NONE = 0
    FILE = 0x1
    FOLDER = 0x2

class StorageLibraryChangeType(enum.IntEnum):
    CREATED = 0
    DELETED = 1
    MOVED_OR_RENAMED = 2
    CONTENTS_CHANGED = 3
    MOVED_OUT_OF_LIBRARY = 4
    MOVED_INTO_LIBRARY = 5
    CONTENTS_REPLACED = 6
    INDEXING_STATUS_CHANGED = 7
    ENCRYPTION_CHANGED = 8
    CHANGE_TRACKING_LOST = 9

class StorageOpenOptions(enum.IntFlag):
    NONE = 0
    ALLOW_ONLY_READERS = 0x1
    ALLOW_READERS_AND_WRITERS = 0x2

class StreamedFileFailureMode(enum.IntEnum):
    FAILED = 0
    CURRENTLY_UNAVAILABLE = 1
    INCOMPLETE = 2

Self = typing.TypeVar('Self')

class AppDataPaths(winsdk.system.Object):
    cookies: str
    desktop: str
    documents: str
    favorites: str
    history: str
    internet_cache: str
    local_app_data: str
    program_data: str
    roaming_app_data: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AppDataPaths: ...
    @staticmethod
    def get_default() -> typing.Optional[AppDataPaths]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[AppDataPaths]: ...

class ApplicationData(winsdk.system.Object):
    local_folder: typing.Optional[StorageFolder]
    local_settings: typing.Optional[ApplicationDataContainer]
    roaming_folder: typing.Optional[StorageFolder]
    roaming_settings: typing.Optional[ApplicationDataContainer]
    roaming_storage_quota: winsdk.system.UInt64
    temporary_folder: typing.Optional[StorageFolder]
    version: winsdk.system.UInt32
    local_cache_folder: typing.Optional[StorageFolder]
    shared_local_folder: typing.Optional[StorageFolder]
    current: typing.ClassVar[typing.Optional[ApplicationData]]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationData: ...
    @typing.overload
    def clear_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def clear_async(self, locality: ApplicationDataLocality) -> winsdk.windows.foundation.IAsyncAction: ...
    def clear_publisher_cache_folder_async(self, folder_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    def close(self) -> None: ...
    @staticmethod
    def get_for_user_async(user: typing.Optional[winsdk.windows.system.User]) -> winsdk.windows.foundation.IAsyncOperation[ApplicationData]: ...
    def get_publisher_cache_folder(self, folder_name: str) -> typing.Optional[StorageFolder]: ...
    def set_version_async(self, desired_version: winsdk.system.UInt32, handler: typing.Optional[ApplicationDataSetVersionHandler]) -> winsdk.windows.foundation.IAsyncAction: ...
    def signal_data_changed(self) -> None: ...
    def add_data_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[ApplicationData, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_data_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ApplicationDataCompositeValue(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationDataCompositeValue: ...
    def __new__(cls: typing.Type[ApplicationDataCompositeValue]) -> ApplicationDataCompositeValue:...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: str) -> None: ...
    def add_map_changed(self, vhnd: winsdk.windows.foundation.collections.MapChangedEventHandler[str, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class ApplicationDataContainer(winsdk.system.Object):
    containers: typing.Optional[winsdk.windows.foundation.collections.IMapView[str, ApplicationDataContainer]]
    locality: ApplicationDataLocality
    name: str
    values: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationDataContainer: ...
    def close(self) -> None: ...
    def create_container(self, name: str, disposition: ApplicationDataCreateDisposition) -> typing.Optional[ApplicationDataContainer]: ...
    def delete_container(self, name: str) -> None: ...

class ApplicationDataContainerSettings(winsdk.system.Object, typing.MutableMapping[str, winsdk.system.Object]):
    size: winsdk.system.UInt32
    def __len__(self) -> int: ...
    def __iter__(self) -> typing.Iterator[str]: ...
    def __contains__(self, key: object) -> bool:...
    def __setitem__(self, key: str, value: winsdk.system.Object) -> None: ...
    def __getitem__(self, key: str) -> winsdk.system.Object: ...
    def __delitem__(self, key: str) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ApplicationDataContainerSettings: ...
    def clear(self) -> None: ...
    def first(self) -> typing.Optional[winsdk.windows.foundation.collections.IIterator[winsdk.windows.foundation.collections.IKeyValuePair[str, winsdk.system.Object]]]: ...
    def get_view(self) -> typing.Optional[winsdk.windows.foundation.collections.IMapView[str, winsdk.system.Object]]: ...
    def has_key(self, key: str) -> winsdk.system.Boolean: ...
    def insert(self, key: str, value: typing.Optional[winsdk.system.Object]) -> winsdk.system.Boolean: ...
    def lookup(self, key: str) -> typing.Optional[winsdk.system.Object]: ...
    def remove(self, key: str) -> None: ...
    def add_map_changed(self, vhnd: winsdk.windows.foundation.collections.MapChangedEventHandler[str, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_map_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CachedFileManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CachedFileManager: ...
    @staticmethod
    def complete_updates_async(file: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.provider.FileUpdateStatus]: ...
    @staticmethod
    def defer_updates(file: typing.Optional[IStorageFile]) -> None: ...

class DownloadsFolder(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DownloadsFolder: ...
    @typing.overload
    @staticmethod
    def create_file_async(desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    @staticmethod
    def create_file_async(desired_name: str, option: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    @staticmethod
    def create_file_for_user_async(user: typing.Optional[winsdk.windows.system.User], desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    @staticmethod
    def create_file_for_user_async(user: typing.Optional[winsdk.windows.system.User], desired_name: str, option: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    @staticmethod
    def create_folder_async(desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    @staticmethod
    def create_folder_async(desired_name: str, option: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    @staticmethod
    def create_folder_for_user_async(user: typing.Optional[winsdk.windows.system.User], desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    @staticmethod
    def create_folder_for_user_async(user: typing.Optional[winsdk.windows.system.User], desired_name: str, option: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...

class FileIO(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> FileIO: ...
    @typing.overload
    @staticmethod
    def append_lines_async(file: typing.Optional[IStorageFile], lines: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_lines_async(file: typing.Optional[IStorageFile], lines: typing.Iterable[str], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_text_async(file: typing.Optional[IStorageFile], contents: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_text_async(file: typing.Optional[IStorageFile], contents: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def read_buffer_async(file: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    @staticmethod
    def read_lines_async(file: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[str]]: ...
    @typing.overload
    @staticmethod
    def read_lines_async(file: typing.Optional[IStorageFile], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[str]]: ...
    @typing.overload
    @staticmethod
    def read_text_async(file: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @typing.overload
    @staticmethod
    def read_text_async(file: typing.Optional[IStorageFile], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def write_buffer_async(file: typing.Optional[IStorageFile], buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def write_bytes_async(file: typing.Optional[IStorageFile], buffer: winsdk.system.Array[winsdk.system.UInt8]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_lines_async(file: typing.Optional[IStorageFile], lines: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_lines_async(file: typing.Optional[IStorageFile], lines: typing.Iterable[str], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_text_async(file: typing.Optional[IStorageFile], contents: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_text_async(file: typing.Optional[IStorageFile], contents: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...

class KnownFolders(winsdk.system.Object):
    camera_roll: typing.ClassVar[typing.Optional[StorageFolder]]
    playlists: typing.ClassVar[typing.Optional[StorageFolder]]
    saved_pictures: typing.ClassVar[typing.Optional[StorageFolder]]
    documents_library: typing.ClassVar[typing.Optional[StorageFolder]]
    home_group: typing.ClassVar[typing.Optional[StorageFolder]]
    media_server_devices: typing.ClassVar[typing.Optional[StorageFolder]]
    music_library: typing.ClassVar[typing.Optional[StorageFolder]]
    pictures_library: typing.ClassVar[typing.Optional[StorageFolder]]
    removable_devices: typing.ClassVar[typing.Optional[StorageFolder]]
    videos_library: typing.ClassVar[typing.Optional[StorageFolder]]
    app_captures: typing.ClassVar[typing.Optional[StorageFolder]]
    objects3_d: typing.ClassVar[typing.Optional[StorageFolder]]
    recorded_calls: typing.ClassVar[typing.Optional[StorageFolder]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> KnownFolders: ...
    @staticmethod
    def get_folder_async(folder_id: KnownFolderId) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @staticmethod
    def get_folder_for_user_async(user: typing.Optional[winsdk.windows.system.User], folder_id: KnownFolderId) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @staticmethod
    def request_access_async(folder_id: KnownFolderId) -> winsdk.windows.foundation.IAsyncOperation[KnownFoldersAccessStatus]: ...
    @staticmethod
    def request_access_for_user_async(user: typing.Optional[winsdk.windows.system.User], folder_id: KnownFolderId) -> winsdk.windows.foundation.IAsyncOperation[KnownFoldersAccessStatus]: ...

class PathIO(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> PathIO: ...
    @typing.overload
    @staticmethod
    def append_lines_async(absolute_path: str, lines: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_lines_async(absolute_path: str, lines: typing.Iterable[str], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_text_async(absolute_path: str, contents: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def append_text_async(absolute_path: str, contents: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def read_buffer_async(absolute_path: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IBuffer]: ...
    @typing.overload
    @staticmethod
    def read_lines_async(absolute_path: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[str]]: ...
    @typing.overload
    @staticmethod
    def read_lines_async(absolute_path: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVector[str]]: ...
    @typing.overload
    @staticmethod
    def read_text_async(absolute_path: str) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @typing.overload
    @staticmethod
    def read_text_async(absolute_path: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    @staticmethod
    def write_buffer_async(absolute_path: str, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def write_bytes_async(absolute_path: str, buffer: winsdk.system.Array[winsdk.system.UInt8]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_lines_async(absolute_path: str, lines: typing.Iterable[str]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_lines_async(absolute_path: str, lines: typing.Iterable[str], encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_text_async(absolute_path: str, contents: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    @staticmethod
    def write_text_async(absolute_path: str, contents: str, encoding: winsdk.windows.storage.streams.UnicodeEncoding) -> winsdk.windows.foundation.IAsyncAction: ...

class SetVersionDeferral(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SetVersionDeferral: ...
    def complete(self) -> None: ...

class SetVersionRequest(winsdk.system.Object):
    current_version: winsdk.system.UInt32
    desired_version: winsdk.system.UInt32
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SetVersionRequest: ...
    def get_deferral(self) -> typing.Optional[SetVersionDeferral]: ...

class StorageFile(winsdk.system.Object):
    content_type: str
    file_type: str
    is_available: winsdk.system.Boolean
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    display_name: str
    display_type: str
    folder_relative_id: str
    properties: typing.Optional[winsdk.windows.storage.fileproperties.StorageItemContentProperties]
    provider: typing.Optional[StorageProvider]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageFile: ...
    def copy_and_replace_async(self, file_to_replace: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @staticmethod
    def create_streamed_file_async(display_name_with_extension: str, data_requested: typing.Optional[StreamedFileDataRequestedHandler], thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @staticmethod
    def create_streamed_file_from_uri_async(display_name_with_extension: str, uri: typing.Optional[winsdk.windows.foundation.Uri], thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    @staticmethod
    def get_file_from_application_uri_async(uri: typing.Optional[winsdk.windows.foundation.Uri]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @staticmethod
    def get_file_from_path_async(path: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @staticmethod
    def get_file_from_path_for_user_async(user: typing.Optional[winsdk.windows.system.User], path: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    def get_parent_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    def is_equal(self, item: typing.Optional[IStorageItem]) -> winsdk.system.Boolean: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    def move_and_replace_async(self, file_to_replace: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def open_async(self, access_mode: FileAccessMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    @typing.overload
    def open_async(self, access_mode: FileAccessMode, options: StorageOpenOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...
    def open_sequential_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IInputStream]: ...
    @typing.overload
    def open_transacted_write_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageStreamTransaction]: ...
    @typing.overload
    def open_transacted_write_async(self, options: StorageOpenOptions) -> winsdk.windows.foundation.IAsyncOperation[StorageStreamTransaction]: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...
    @staticmethod
    def replace_with_streamed_file_async(file_to_replace: typing.Optional[IStorageFile], data_requested: typing.Optional[StreamedFileDataRequestedHandler], thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @staticmethod
    def replace_with_streamed_file_from_uri_async(file_to_replace: typing.Optional[IStorageFile], uri: typing.Optional[winsdk.windows.foundation.Uri], thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...

class StorageFolder(winsdk.system.Object):
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    display_name: str
    display_type: str
    folder_relative_id: str
    properties: typing.Optional[winsdk.windows.storage.fileproperties.StorageItemContentProperties]
    provider: typing.Optional[StorageProvider]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageFolder: ...
    def are_query_options_supported(self, query_options: typing.Optional[winsdk.windows.storage.search.QueryOptions]) -> winsdk.system.Boolean: ...
    @typing.overload
    def create_file_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def create_file_async(self, desired_name: str, options: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def create_file_query(self) -> typing.Optional[winsdk.windows.storage.search.StorageFileQueryResult]: ...
    @typing.overload
    def create_file_query(self, query: winsdk.windows.storage.search.CommonFileQuery) -> typing.Optional[winsdk.windows.storage.search.StorageFileQueryResult]: ...
    def create_file_query_with_options(self, query_options: typing.Optional[winsdk.windows.storage.search.QueryOptions]) -> typing.Optional[winsdk.windows.storage.search.StorageFileQueryResult]: ...
    @typing.overload
    def create_folder_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def create_folder_async(self, desired_name: str, options: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def create_folder_query(self) -> typing.Optional[winsdk.windows.storage.search.StorageFolderQueryResult]: ...
    @typing.overload
    def create_folder_query(self, query: winsdk.windows.storage.search.CommonFolderQuery) -> typing.Optional[winsdk.windows.storage.search.StorageFolderQueryResult]: ...
    def create_folder_query_with_options(self, query_options: typing.Optional[winsdk.windows.storage.search.QueryOptions]) -> typing.Optional[winsdk.windows.storage.search.StorageFolderQueryResult]: ...
    def create_item_query(self) -> typing.Optional[winsdk.windows.storage.search.StorageItemQueryResult]: ...
    def create_item_query_with_options(self, query_options: typing.Optional[winsdk.windows.storage.search.QueryOptions]) -> typing.Optional[winsdk.windows.storage.search.StorageItemQueryResult]: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    def get_file_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def get_files_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFile]]: ...
    @typing.overload
    def get_files_async(self, query: winsdk.windows.storage.search.CommonFileQuery) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFile]]: ...
    @typing.overload
    def get_files_async(self, query: winsdk.windows.storage.search.CommonFileQuery, start_index: winsdk.system.UInt32, max_items_to_retrieve: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFile]]: ...
    def get_folder_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @staticmethod
    def get_folder_from_path_async(path: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @staticmethod
    def get_folder_from_path_for_user_async(user: typing.Optional[winsdk.windows.system.User], path: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def get_folders_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFolder]]: ...
    @typing.overload
    def get_folders_async(self, query: winsdk.windows.storage.search.CommonFolderQuery) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFolder]]: ...
    @typing.overload
    def get_folders_async(self, query: winsdk.windows.storage.search.CommonFolderQuery, start_index: winsdk.system.UInt32, max_items_to_retrieve: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFolder]]: ...
    def get_indexed_state_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.search.IndexedState]: ...
    def get_item_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[IStorageItem]: ...
    @typing.overload
    def get_items_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[IStorageItem]]: ...
    @typing.overload
    def get_items_async(self, start_index: winsdk.system.UInt32, max_items_to_retrieve: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[IStorageItem]]: ...
    def get_parent_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    def is_common_file_query_supported(self, query: winsdk.windows.storage.search.CommonFileQuery) -> winsdk.system.Boolean: ...
    def is_common_folder_query_supported(self, query: winsdk.windows.storage.search.CommonFolderQuery) -> winsdk.system.Boolean: ...
    def is_equal(self, item: typing.Optional[IStorageItem]) -> winsdk.system.Boolean: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def try_get_change_tracker(self) -> typing.Optional[StorageLibraryChangeTracker]: ...
    def try_get_item_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[IStorageItem]: ...

class StorageLibrary(winsdk.system.Object):
    folders: typing.Optional[winsdk.windows.foundation.collections.IObservableVector[StorageFolder]]
    save_folder: typing.Optional[StorageFolder]
    change_tracker: typing.Optional[StorageLibraryChangeTracker]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibrary: ...
    def are_folder_suggestions_available_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def get_library_async(library_id: KnownLibraryId) -> winsdk.windows.foundation.IAsyncOperation[StorageLibrary]: ...
    @staticmethod
    def get_library_for_user_async(user: typing.Optional[winsdk.windows.system.User], library_id: KnownLibraryId) -> winsdk.windows.foundation.IAsyncOperation[StorageLibrary]: ...
    def request_add_folder_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    def request_remove_folder_async(self, folder: typing.Optional[StorageFolder]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def add_definition_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[StorageLibrary, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_definition_changed(self, event_cookie: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class StorageLibraryChange(winsdk.system.Object):
    change_type: StorageLibraryChangeType
    path: str
    previous_path: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibraryChange: ...
    def get_storage_item_async(self) -> winsdk.windows.foundation.IAsyncOperation[IStorageItem]: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...

class StorageLibraryChangeReader(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibraryChangeReader: ...
    def accept_changes_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_last_change_id(self) -> winsdk.system.UInt64: ...
    def read_batch_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageLibraryChange]]: ...

class StorageLibraryChangeTracker(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibraryChangeTracker: ...
    def disable(self) -> None: ...
    @typing.overload
    def enable(self) -> None: ...
    @typing.overload
    def enable(self, options: typing.Optional[StorageLibraryChangeTrackerOptions]) -> None: ...
    def get_change_reader(self) -> typing.Optional[StorageLibraryChangeReader]: ...
    def reset(self) -> None: ...

class StorageLibraryChangeTrackerOptions(winsdk.system.Object):
    track_change_details: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibraryChangeTrackerOptions: ...
    def __new__(cls: typing.Type[StorageLibraryChangeTrackerOptions]) -> StorageLibraryChangeTrackerOptions:...

class StorageLibraryLastChangeId(winsdk.system.Object):
    unknown: typing.ClassVar[winsdk.system.UInt64]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageLibraryLastChangeId: ...

class StorageProvider(winsdk.system.Object):
    display_name: str
    id: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageProvider: ...
    def is_property_supported_for_partial_file_async(self, property_canonical_name: str) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...

class StorageStreamTransaction(winsdk.system.Object):
    stream: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStream]
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StorageStreamTransaction: ...
    def close(self) -> None: ...
    def commit_async(self) -> winsdk.windows.foundation.IAsyncAction: ...

class StreamedFileDataRequest(winsdk.system.Object):
    def __enter__(self: Self) -> Self: ...
    def __exit__(self, *args) -> None: ...
    @staticmethod
    def _from(obj: winsdk.system.Object) -> StreamedFileDataRequest: ...
    def close(self) -> None: ...
    def fail_and_close(self, failure_mode: StreamedFileFailureMode) -> None: ...
    def flush_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    def write_async(self, buffer: typing.Optional[winsdk.windows.storage.streams.IBuffer]) -> winsdk.windows.foundation.IAsyncOperationWithProgress[winsdk.system.UInt32, winsdk.system.UInt32]: ...

class SystemAudioProperties(winsdk.system.Object):
    encoding_bitrate: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemAudioProperties: ...

class SystemDataPaths(winsdk.system.Object):
    fonts: str
    program_data: str
    public: str
    public_desktop: str
    public_documents: str
    public_downloads: str
    public_music: str
    public_pictures: str
    public_videos: str
    system: str
    system_arm: str
    system_host: str
    system_x64: str
    system_x86: str
    user_profiles: str
    windows: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemDataPaths: ...
    @staticmethod
    def get_default() -> typing.Optional[SystemDataPaths]: ...

class SystemGPSProperties(winsdk.system.Object):
    latitude_decimal: str
    longitude_decimal: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemGPSProperties: ...

class SystemImageProperties(winsdk.system.Object):
    horizontal_size: str
    vertical_size: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemImageProperties: ...

class SystemMediaProperties(winsdk.system.Object):
    duration: str
    producer: str
    publisher: str
    sub_title: str
    writer: str
    year: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMediaProperties: ...

class SystemMusicProperties(winsdk.system.Object):
    album_artist: str
    album_title: str
    artist: str
    composer: str
    conductor: str
    display_artist: str
    genre: str
    track_number: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemMusicProperties: ...

class SystemPhotoProperties(winsdk.system.Object):
    camera_manufacturer: str
    camera_model: str
    date_taken: str
    orientation: str
    people_names: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemPhotoProperties: ...

class SystemProperties(winsdk.system.Object):
    audio: typing.ClassVar[typing.Optional[SystemAudioProperties]]
    author: typing.ClassVar[str]
    comment: typing.ClassVar[str]
    g_p_s: typing.ClassVar[typing.Optional[SystemGPSProperties]]
    image: typing.ClassVar[typing.Optional[SystemImageProperties]]
    item_name_display: typing.ClassVar[str]
    keywords: typing.ClassVar[str]
    media: typing.ClassVar[typing.Optional[SystemMediaProperties]]
    music: typing.ClassVar[typing.Optional[SystemMusicProperties]]
    photo: typing.ClassVar[typing.Optional[SystemPhotoProperties]]
    rating: typing.ClassVar[str]
    title: typing.ClassVar[str]
    video: typing.ClassVar[typing.Optional[SystemVideoProperties]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemProperties: ...

class SystemVideoProperties(winsdk.system.Object):
    director: str
    frame_height: str
    frame_width: str
    orientation: str
    total_bitrate: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SystemVideoProperties: ...

class UserDataPaths(winsdk.system.Object):
    camera_roll: str
    cookies: str
    desktop: str
    documents: str
    downloads: str
    favorites: str
    history: str
    internet_cache: str
    local_app_data: str
    local_app_data_low: str
    music: str
    pictures: str
    profile: str
    recent: str
    roaming_app_data: str
    saved_pictures: str
    screenshots: str
    templates: str
    videos: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> UserDataPaths: ...
    @staticmethod
    def get_default() -> typing.Optional[UserDataPaths]: ...
    @staticmethod
    def get_for_user(user: typing.Optional[winsdk.windows.system.User]) -> typing.Optional[UserDataPaths]: ...

class IStorageFile(winsdk.system.Object):
    content_type: str
    file_type: str
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageFile: ...
    def copy_and_replace_async(self, file_to_replace: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder]) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def copy_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    def move_and_replace_async(self, file_to_replace: typing.Optional[IStorageFile]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder]) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def move_async(self, destination_folder: typing.Optional[IStorageFolder], desired_new_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def open_async(self, access_mode: FileAccessMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def open_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]: ...
    def open_sequential_read_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IInputStream]: ...
    def open_transacted_write_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageStreamTransaction]: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...

class IStorageFile2(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageFile2: ...
    def open_async(self, access_mode: FileAccessMode, options: StorageOpenOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.streams.IRandomAccessStream]: ...
    def open_transacted_write_async(self, options: StorageOpenOptions) -> winsdk.windows.foundation.IAsyncOperation[StorageStreamTransaction]: ...

class IStorageFilePropertiesWithAvailability(winsdk.system.Object):
    is_available: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageFilePropertiesWithAvailability: ...

class IStorageFolder(winsdk.system.Object):
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageFolder: ...
    @typing.overload
    def create_file_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def create_file_async(self, desired_name: str, options: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    @typing.overload
    def create_folder_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def create_folder_async(self, desired_name: str, options: CreationCollisionOption) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    def get_file_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFile]: ...
    def get_files_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFile]]: ...
    def get_folder_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    def get_folders_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[StorageFolder]]: ...
    def get_item_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[IStorageItem]: ...
    def get_items_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IVectorView[IStorageItem]]: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...

class IStorageFolder2(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageFolder2: ...
    def try_get_item_async(self, name: str) -> winsdk.windows.foundation.IAsyncOperation[IStorageItem]: ...

class IStorageItem(winsdk.system.Object):
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItem: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...

class IStorageItem2(winsdk.system.Object):
    attributes: FileAttributes
    date_created: datetime.datetime
    name: str
    path: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItem2: ...
    @typing.overload
    def delete_async(self) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def delete_async(self, option: StorageDeleteOption) -> winsdk.windows.foundation.IAsyncAction: ...
    def get_basic_properties_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.BasicProperties]: ...
    def get_parent_async(self) -> winsdk.windows.foundation.IAsyncOperation[StorageFolder]: ...
    def is_equal(self, item: typing.Optional[IStorageItem]) -> winsdk.system.Boolean: ...
    def is_of_type(self, type: StorageItemTypes) -> winsdk.system.Boolean: ...
    @typing.overload
    def rename_async(self, desired_name: str) -> winsdk.windows.foundation.IAsyncAction: ...
    @typing.overload
    def rename_async(self, desired_name: str, option: NameCollisionOption) -> winsdk.windows.foundation.IAsyncAction: ...

class IStorageItemProperties(winsdk.system.Object):
    display_name: str
    display_type: str
    folder_relative_id: str
    properties: typing.Optional[winsdk.windows.storage.fileproperties.StorageItemContentProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItemProperties: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...

class IStorageItemProperties2(winsdk.system.Object):
    display_name: str
    display_type: str
    folder_relative_id: str
    properties: typing.Optional[winsdk.windows.storage.fileproperties.StorageItemContentProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItemProperties2: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_scaled_image_as_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...

class IStorageItemPropertiesWithProvider(winsdk.system.Object):
    provider: typing.Optional[StorageProvider]
    display_name: str
    display_type: str
    folder_relative_id: str
    properties: typing.Optional[winsdk.windows.storage.fileproperties.StorageItemContentProperties]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStorageItemPropertiesWithProvider: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...
    @typing.overload
    def get_thumbnail_async(self, mode: winsdk.windows.storage.fileproperties.ThumbnailMode, requested_size: winsdk.system.UInt32, options: winsdk.windows.storage.fileproperties.ThumbnailOptions) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.storage.fileproperties.StorageItemThumbnail]: ...

class IStreamedFileDataRequest(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IStreamedFileDataRequest: ...
    def fail_and_close(self, failure_mode: StreamedFileFailureMode) -> None: ...

ApplicationDataSetVersionHandler = typing.Callable[[typing.Optional[SetVersionRequest]], None]

StreamedFileDataRequestedHandler = typing.Callable[[typing.Optional[StreamedFileDataRequest]], None]




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input.Core")

try:
    import winsdk.windows.applicationmodel.core
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

try:
    import winsdk.windows.ui.input
except ImportError:
    pass


RadialControllerIndependentInputSource = _ns_module.RadialControllerIndependentInputSource



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.devices.enumeration
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.storage.streams
import winsdk.windows.ui.popups

class DialAppLaunchResult(enum.IntEnum):
    LAUNCHED = 0
    FAILED_TO_LAUNCH = 1
    NOT_FOUND = 2
    NETWORK_FAILURE = 3

class DialAppState(enum.IntEnum):
    UNKNOWN = 0
    STOPPED = 1
    RUNNING = 2
    NETWORK_FAILURE = 3

class DialAppStopResult(enum.IntEnum):
    STOPPED = 0
    STOP_FAILED = 1
    OPERATION_NOT_SUPPORTED = 2
    NETWORK_FAILURE = 3

class DialDeviceDisplayStatus(enum.IntEnum):
    NONE = 0
    CONNECTING = 1
    CONNECTED = 2
    DISCONNECTING = 3
    DISCONNECTED = 4
    ERROR = 5

Self = typing.TypeVar('Self')

class DialApp(winsdk.system.Object):
    app_name: str
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialApp: ...
    def get_app_state_async(self) -> winsdk.windows.foundation.IAsyncOperation[DialAppStateDetails]: ...
    def request_launch_async(self, app_argument: str) -> winsdk.windows.foundation.IAsyncOperation[DialAppLaunchResult]: ...
    def stop_async(self) -> winsdk.windows.foundation.IAsyncOperation[DialAppStopResult]: ...

class DialAppStateDetails(winsdk.system.Object):
    full_xml: str
    state: DialAppState
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialAppStateDetails: ...

class DialDevice(winsdk.system.Object):
    id: str
    friendly_name: str
    thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamReference]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialDevice: ...
    @staticmethod
    def device_info_supports_dial_async(device: typing.Optional[winsdk.windows.devices.enumeration.DeviceInformation]) -> winsdk.windows.foundation.IAsyncOperation[winsdk.system.Boolean]: ...
    @staticmethod
    def from_id_async(value: str) -> winsdk.windows.foundation.IAsyncOperation[DialDevice]: ...
    @staticmethod
    def get_device_selector(app_name: str) -> str: ...
    def get_dial_app(self, app_name: str) -> typing.Optional[DialApp]: ...

class DialDevicePicker(winsdk.system.Object):
    appearance: typing.Optional[winsdk.windows.devices.enumeration.DevicePickerAppearance]
    filter: typing.Optional[DialDevicePickerFilter]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialDevicePicker: ...
    def __new__(cls: typing.Type[DialDevicePicker]) -> DialDevicePicker:...
    def hide(self) -> None: ...
    @typing.overload
    def pick_single_dial_device_async(self, selection: winsdk.windows.foundation.Rect) -> winsdk.windows.foundation.IAsyncOperation[DialDevice]: ...
    @typing.overload
    def pick_single_dial_device_async(self, selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement) -> winsdk.windows.foundation.IAsyncOperation[DialDevice]: ...
    def set_display_status(self, device: typing.Optional[DialDevice], status: DialDeviceDisplayStatus) -> None: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect) -> None: ...
    @typing.overload
    def show(self, selection: winsdk.windows.foundation.Rect, preferred_placement: winsdk.windows.ui.popups.Placement) -> None: ...
    def add_dial_device_picker_dismissed(self, handler: winsdk.windows.foundation.TypedEventHandler[DialDevicePicker, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_dial_device_picker_dismissed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_dial_device_selected(self, handler: winsdk.windows.foundation.TypedEventHandler[DialDevicePicker, DialDeviceSelectedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_dial_device_selected(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...
    def add_disconnect_button_clicked(self, handler: winsdk.windows.foundation.TypedEventHandler[DialDevicePicker, DialDisconnectButtonClickedEventArgs]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_disconnect_button_clicked(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class DialDevicePickerFilter(winsdk.system.Object):
    supported_app_names: typing.Optional[winsdk.windows.foundation.collections.IVector[str]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialDevicePickerFilter: ...

class DialDeviceSelectedEventArgs(winsdk.system.Object):
    selected_dial_device: typing.Optional[DialDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialDeviceSelectedEventArgs: ...

class DialDisconnectButtonClickedEventArgs(winsdk.system.Object):
    device: typing.Optional[DialDevice]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialDisconnectButtonClickedEventArgs: ...

class DialReceiverApp(winsdk.system.Object):
    current: typing.ClassVar[typing.Optional[DialReceiverApp]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> DialReceiverApp: ...
    def get_additional_data_async(self) -> winsdk.windows.foundation.IAsyncOperation[winsdk.windows.foundation.collections.IMap[str, str]]: ...
    def get_unique_device_name_async(self) -> winsdk.windows.foundation.IAsyncOperation[str]: ...
    def set_additional_data_async(self, additional_data: typing.Iterable[winsdk.windows.foundation.collections.IKeyValuePair[str, str]]) -> winsdk.windows.foundation.IAsyncAction: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.Media.Render")

class AudioRenderCategory(enum.IntEnum):
    OTHER = 0
    FOREGROUND_ONLY_MEDIA = 1
    BACKGROUND_CAPABLE_MEDIA = 2
    COMMUNICATIONS = 3
    ALERTS = 4
    SOUND_EFFECTS = 5
    GAME_EFFECTS = 6
    GAME_MEDIA = 7
    GAME_CHAT = 8
    SPEECH = 9
    MOVIE = 10
    MEDIA = 11

_ns_module._register_AudioRenderCategory(AudioRenderCategory)




# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Email")

try:
    import winsdk.windows.applicationmodel.appointments
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.security.cryptography.certificates
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

class EmailAttachmentDownloadState(enum.IntEnum):
    NOT_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailBatchStatus(enum.IntEnum):
    SUCCESS = 0
    SERVER_SEARCH_SYNC_MANAGER_ERROR = 1
    SERVER_SEARCH_UNKNOWN_ERROR = 2

class EmailCertificateValidationStatus(enum.IntEnum):
    SUCCESS = 0
    NO_MATCH = 1
    INVALID_USAGE = 2
    INVALID_CERTIFICATE = 3
    REVOKED = 4
    CHAIN_REVOKED = 5
    REVOCATION_SERVER_FAILURE = 6
    EXPIRED = 7
    UNTRUSTED = 8
    SERVER_ERROR = 9
    UNKNOWN_FAILURE = 10

class EmailFlagState(enum.IntEnum):
    UNFLAGGED = 0
    FLAGGED = 1
    COMPLETED = 2
    CLEARED = 3

class EmailImportance(enum.IntEnum):
    NORMAL = 0
    HIGH = 1
    LOW = 2

class EmailMailboxActionKind(enum.IntEnum):
    MARK_MESSAGE_AS_SEEN = 0
    MARK_MESSAGE_READ = 1
    CHANGE_MESSAGE_FLAG_STATE = 2
    MOVE_MESSAGE = 3
    SAVE_DRAFT = 4
    SEND_MESSAGE = 5
    CREATE_RESPONSE_REPLY_MESSAGE = 6
    CREATE_RESPONSE_REPLY_ALL_MESSAGE = 7
    CREATE_RESPONSE_FORWARD_MESSAGE = 8
    MOVE_FOLDER = 9
    MARK_FOLDER_FOR_SYNC_ENABLED = 10

class EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation(enum.IntEnum):
    NONE = 0
    STRONG_ALGORITHM = 1
    ANY_ALGORITHM = 2

class EmailMailboxAutoReplyMessageResponseKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMailboxChangeType(enum.IntEnum):
    MESSAGE_CREATED = 0
    MESSAGE_MODIFIED = 1
    MESSAGE_DELETED = 2
    FOLDER_CREATED = 3
    FOLDER_MODIFIED = 4
    FOLDER_DELETED = 5
    CHANGE_TRACKING_LOST = 6

class EmailMailboxCreateFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    NAME_COLLISION = 5
    SERVER_REJECTED = 6

class EmailMailboxDeleteFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxEmptyFolderStatus(enum.IntEnum):
    SUCCESS = 0
    NETWORK_ERROR = 1
    PERMISSIONS_ERROR = 2
    SERVER_ERROR = 3
    UNKNOWN_FAILURE = 4
    COULD_NOT_DELETE_EVERYTHING = 5

class EmailMailboxOtherAppReadAccess(enum.IntEnum):
    SYSTEM_ONLY = 0
    FULL = 1
    NONE = 2

class EmailMailboxOtherAppWriteAccess(enum.IntEnum):
    NONE = 0
    LIMITED = 1

class EmailMailboxSmimeEncryptionAlgorithm(enum.IntEnum):
    ANY = 0
    TRIPLE_DES = 1
    DES = 2
    R_C2128_BIT = 3
    R_C264_BIT = 4
    R_C240_BIT = 5

class EmailMailboxSmimeSigningAlgorithm(enum.IntEnum):
    ANY = 0
    SHA1 = 1
    M_D5 = 2

class EmailMailboxSyncStatus(enum.IntEnum):
    IDLE = 0
    SYNCING = 1
    UP_TO_DATE = 2
    AUTHENTICATION_ERROR = 3
    POLICY_ERROR = 4
    UNKNOWN_ERROR = 5
    MANUAL_ACCOUNT_REMOVAL_REQUIRED = 6

class EmailMeetingResponseType(enum.IntEnum):
    ACCEPT = 0
    DECLINE = 1
    TENTATIVE = 2

class EmailMessageBodyKind(enum.IntEnum):
    HTML = 0
    PLAIN_TEXT = 1

class EmailMessageDownloadState(enum.IntEnum):
    PARTIALLY_DOWNLOADED = 0
    DOWNLOADING = 1
    DOWNLOADED = 2
    FAILED = 3

class EmailMessageResponseKind(enum.IntEnum):
    NONE = 0
    REPLY = 1
    REPLY_ALL = 2
    FORWARD = 3

class EmailMessageSmimeKind(enum.IntEnum):
    NONE = 0
    CLEAR_SIGNED = 1
    OPAQUE_SIGNED = 2
    ENCRYPTED = 3

class EmailQueryKind(enum.IntEnum):
    ALL = 0
    IMPORTANT = 1
    FLAGGED = 2
    UNREAD = 3
    READ = 4
    UNSEEN = 5

class EmailQuerySearchFields(enum.IntFlag):
    NONE = 0
    SUBJECT = 0x1
    SENDER = 0x2
    PREVIEW = 0x4
    RECIPIENTS = 0x8
    ALL = 0xffffffff

class EmailQuerySearchScope(enum.IntEnum):
    LOCAL = 0
    SERVER = 1

class EmailQuerySortDirection(enum.IntEnum):
    DESCENDING = 0
    ASCENDING = 1

class EmailQuerySortProperty(enum.IntEnum):
    DATE = 0

class EmailRecipientResolutionStatus(enum.IntEnum):
    SUCCESS = 0
    RECIPIENT_NOT_FOUND = 1
    AMBIGUOUS_RECIPIENT = 2
    NO_CERTIFICATE = 3
    CERTIFICATE_REQUEST_LIMIT_REACHED = 4
    CANNOT_RESOLVE_DISTRIBUTION_LIST = 5
    SERVER_ERROR = 6
    UNKNOWN_FAILURE = 7

class EmailSpecialFolderKind(enum.IntEnum):
    NONE = 0
    ROOT = 1
    INBOX = 2
    OUTBOX = 3
    DRAFTS = 4
    DELETED_ITEMS = 5
    SENT = 6

class EmailStoreAccessType(enum.IntEnum):
    APP_MAILBOXES_READ_WRITE = 0
    ALL_MAILBOXES_LIMITED_READ_WRITE = 1

_ns_module._register_EmailAttachmentDownloadState(EmailAttachmentDownloadState)
_ns_module._register_EmailBatchStatus(EmailBatchStatus)
_ns_module._register_EmailCertificateValidationStatus(EmailCertificateValidationStatus)
_ns_module._register_EmailFlagState(EmailFlagState)
_ns_module._register_EmailImportance(EmailImportance)
_ns_module._register_EmailMailboxActionKind(EmailMailboxActionKind)
_ns_module._register_EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation(EmailMailboxAllowedSmimeEncryptionAlgorithmNegotiation)
_ns_module._register_EmailMailboxAutoReplyMessageResponseKind(EmailMailboxAutoReplyMessageResponseKind)
_ns_module._register_EmailMailboxChangeType(EmailMailboxChangeType)
_ns_module._register_EmailMailboxCreateFolderStatus(EmailMailboxCreateFolderStatus)
_ns_module._register_EmailMailboxDeleteFolderStatus(EmailMailboxDeleteFolderStatus)
_ns_module._register_EmailMailboxEmptyFolderStatus(EmailMailboxEmptyFolderStatus)
_ns_module._register_EmailMailboxOtherAppReadAccess(EmailMailboxOtherAppReadAccess)
_ns_module._register_EmailMailboxOtherAppWriteAccess(EmailMailboxOtherAppWriteAccess)
_ns_module._register_EmailMailboxSmimeEncryptionAlgorithm(EmailMailboxSmimeEncryptionAlgorithm)
_ns_module._register_EmailMailboxSmimeSigningAlgorithm(EmailMailboxSmimeSigningAlgorithm)
_ns_module._register_EmailMailboxSyncStatus(EmailMailboxSyncStatus)
_ns_module._register_EmailMeetingResponseType(EmailMeetingResponseType)
_ns_module._register_EmailMessageBodyKind(EmailMessageBodyKind)
_ns_module._register_EmailMessageDownloadState(EmailMessageDownloadState)
_ns_module._register_EmailMessageResponseKind(EmailMessageResponseKind)
_ns_module._register_EmailMessageSmimeKind(EmailMessageSmimeKind)
_ns_module._register_EmailQueryKind(EmailQueryKind)
_ns_module._register_EmailQuerySearchFields(EmailQuerySearchFields)
_ns_module._register_EmailQuerySearchScope(EmailQuerySearchScope)
_ns_module._register_EmailQuerySortDirection(EmailQuerySortDirection)
_ns_module._register_EmailQuerySortProperty(EmailQuerySortProperty)
_ns_module._register_EmailRecipientResolutionStatus(EmailRecipientResolutionStatus)
_ns_module._register_EmailSpecialFolderKind(EmailSpecialFolderKind)
_ns_module._register_EmailStoreAccessType(EmailStoreAccessType)

EmailAttachment = _ns_module.EmailAttachment
EmailConversation = _ns_module.EmailConversation
EmailConversationBatch = _ns_module.EmailConversationBatch
EmailConversationReader = _ns_module.EmailConversationReader
EmailFolder = _ns_module.EmailFolder
EmailIrmInfo = _ns_module.EmailIrmInfo
EmailIrmTemplate = _ns_module.EmailIrmTemplate
EmailItemCounts = _ns_module.EmailItemCounts
EmailMailbox = _ns_module.EmailMailbox
EmailMailboxAction = _ns_module.EmailMailboxAction
EmailMailboxAutoReply = _ns_module.EmailMailboxAutoReply
EmailMailboxAutoReplySettings = _ns_module.EmailMailboxAutoReplySettings
EmailMailboxCapabilities = _ns_module.EmailMailboxCapabilities
EmailMailboxChange = _ns_module.EmailMailboxChange
EmailMailboxChangeReader = _ns_module.EmailMailboxChangeReader
EmailMailboxChangeTracker = _ns_module.EmailMailboxChangeTracker
EmailMailboxChangedDeferral = _ns_module.EmailMailboxChangedDeferral
EmailMailboxChangedEventArgs = _ns_module.EmailMailboxChangedEventArgs
EmailMailboxCreateFolderResult = _ns_module.EmailMailboxCreateFolderResult
EmailMailboxPolicies = _ns_module.EmailMailboxPolicies
EmailMailboxSyncManager = _ns_module.EmailMailboxSyncManager
EmailManager = _ns_module.EmailManager
EmailManagerForUser = _ns_module.EmailManagerForUser
EmailMeetingInfo = _ns_module.EmailMeetingInfo
EmailMessage = _ns_module.EmailMessage
EmailMessageBatch = _ns_module.EmailMessageBatch
EmailMessageReader = _ns_module.EmailMessageReader
EmailQueryOptions = _ns_module.EmailQueryOptions
EmailQueryTextSearch = _ns_module.EmailQueryTextSearch
EmailRecipient = _ns_module.EmailRecipient
EmailRecipientResolutionResult = _ns_module.EmailRecipientResolutionResult
EmailStore = _ns_module.EmailStore
EmailStoreNotificationTriggerDetails = _ns_module.EmailStoreNotificationTriggerDetails



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.UI.Input")

try:
    import winsdk.windows.devices.haptics
except ImportError:
    pass

try:
    import winsdk.windows.devices.input
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.storage.streams
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

class CrossSlidingState(enum.IntEnum):
    STARTED = 0
    DRAGGING = 1
    SELECTING = 2
    SELECT_SPEED_BUMPING = 3
    SPEED_BUMPING = 4
    REARRANGING = 5
    COMPLETED = 6

class DraggingState(enum.IntEnum):
    STARTED = 0
    CONTINUING = 1
    COMPLETED = 2

class EdgeGestureKind(enum.IntEnum):
    TOUCH = 0
    KEYBOARD = 1
    MOUSE = 2

class GazeInputAccessStatus(enum.IntEnum):
    UNSPECIFIED = 0
    ALLOWED = 1
    DENIED_BY_USER = 2
    DENIED_BY_SYSTEM = 3

class GestureSettings(enum.IntFlag):
    NONE = 0
    TAP = 0x1
    DOUBLE_TAP = 0x2
    HOLD = 0x4
    HOLD_WITH_MOUSE = 0x8
    RIGHT_TAP = 0x10
    DRAG = 0x20
    MANIPULATION_TRANSLATE_X = 0x40
    MANIPULATION_TRANSLATE_Y = 0x80
    MANIPULATION_TRANSLATE_RAILS_X = 0x100
    MANIPULATION_TRANSLATE_RAILS_Y = 0x200
    MANIPULATION_ROTATE = 0x400
    MANIPULATION_SCALE = 0x800
    MANIPULATION_TRANSLATE_INERTIA = 0x1000
    MANIPULATION_ROTATE_INERTIA = 0x2000
    MANIPULATION_SCALE_INERTIA = 0x4000
    CROSS_SLIDE = 0x8000
    MANIPULATION_MULTIPLE_FINGER_PANNING = 0x10000

class HoldingState(enum.IntEnum):
    STARTED = 0
    COMPLETED = 1
    CANCELED = 2

class InputActivationState(enum.IntEnum):
    NONE = 0
    DEACTIVATED = 1
    ACTIVATED_NOT_FOREGROUND = 2
    ACTIVATED_IN_FOREGROUND = 3

class PointerUpdateKind(enum.IntEnum):
    OTHER = 0
    LEFT_BUTTON_PRESSED = 1
    LEFT_BUTTON_RELEASED = 2
    RIGHT_BUTTON_PRESSED = 3
    RIGHT_BUTTON_RELEASED = 4
    MIDDLE_BUTTON_PRESSED = 5
    MIDDLE_BUTTON_RELEASED = 6
    X_BUTTON1_PRESSED = 7
    X_BUTTON1_RELEASED = 8
    X_BUTTON2_PRESSED = 9
    X_BUTTON2_RELEASED = 10

class RadialControllerMenuKnownIcon(enum.IntEnum):
    SCROLL = 0
    ZOOM = 1
    UNDO_REDO = 2
    VOLUME = 3
    NEXT_PREVIOUS_TRACK = 4
    RULER = 5
    INK_COLOR = 6
    INK_THICKNESS = 7
    PEN_TYPE = 8

class RadialControllerSystemMenuItemKind(enum.IntEnum):
    SCROLL = 0
    ZOOM = 1
    UNDO_REDO = 2
    VOLUME = 3
    NEXT_PREVIOUS_TRACK = 4

_ns_module._register_CrossSlidingState(CrossSlidingState)
_ns_module._register_DraggingState(DraggingState)
_ns_module._register_EdgeGestureKind(EdgeGestureKind)
_ns_module._register_GazeInputAccessStatus(GazeInputAccessStatus)
_ns_module._register_GestureSettings(GestureSettings)
_ns_module._register_HoldingState(HoldingState)
_ns_module._register_InputActivationState(InputActivationState)
_ns_module._register_PointerUpdateKind(PointerUpdateKind)
_ns_module._register_RadialControllerMenuKnownIcon(RadialControllerMenuKnownIcon)
_ns_module._register_RadialControllerSystemMenuItemKind(RadialControllerSystemMenuItemKind)

CrossSlideThresholds = _ns_module.CrossSlideThresholds
ManipulationDelta = _ns_module.ManipulationDelta
ManipulationVelocities = _ns_module.ManipulationVelocities
AttachableInputObject = _ns_module.AttachableInputObject
CrossSlidingEventArgs = _ns_module.CrossSlidingEventArgs
DraggingEventArgs = _ns_module.DraggingEventArgs
EdgeGesture = _ns_module.EdgeGesture
EdgeGestureEventArgs = _ns_module.EdgeGestureEventArgs
GestureRecognizer = _ns_module.GestureRecognizer
HoldingEventArgs = _ns_module.HoldingEventArgs
InputActivationListener = _ns_module.InputActivationListener
InputActivationListenerActivationChangedEventArgs = _ns_module.InputActivationListenerActivationChangedEventArgs
KeyboardDeliveryInterceptor = _ns_module.KeyboardDeliveryInterceptor
ManipulationCompletedEventArgs = _ns_module.ManipulationCompletedEventArgs
ManipulationInertiaStartingEventArgs = _ns_module.ManipulationInertiaStartingEventArgs
ManipulationStartedEventArgs = _ns_module.ManipulationStartedEventArgs
ManipulationUpdatedEventArgs = _ns_module.ManipulationUpdatedEventArgs
MouseWheelParameters = _ns_module.MouseWheelParameters
PointerPoint = _ns_module.PointerPoint
PointerPointProperties = _ns_module.PointerPointProperties
PointerVisualizationSettings = _ns_module.PointerVisualizationSettings
RadialController = _ns_module.RadialController
RadialControllerButtonClickedEventArgs = _ns_module.RadialControllerButtonClickedEventArgs
RadialControllerButtonHoldingEventArgs = _ns_module.RadialControllerButtonHoldingEventArgs
RadialControllerButtonPressedEventArgs = _ns_module.RadialControllerButtonPressedEventArgs
RadialControllerButtonReleasedEventArgs = _ns_module.RadialControllerButtonReleasedEventArgs
RadialControllerConfiguration = _ns_module.RadialControllerConfiguration
RadialControllerControlAcquiredEventArgs = _ns_module.RadialControllerControlAcquiredEventArgs
RadialControllerMenu = _ns_module.RadialControllerMenu
RadialControllerMenuItem = _ns_module.RadialControllerMenuItem
RadialControllerRotationChangedEventArgs = _ns_module.RadialControllerRotationChangedEventArgs
RadialControllerScreenContact = _ns_module.RadialControllerScreenContact
RadialControllerScreenContactContinuedEventArgs = _ns_module.RadialControllerScreenContactContinuedEventArgs
RadialControllerScreenContactEndedEventArgs = _ns_module.RadialControllerScreenContactEndedEventArgs
RadialControllerScreenContactStartedEventArgs = _ns_module.RadialControllerScreenContactStartedEventArgs
RightTappedEventArgs = _ns_module.RightTappedEventArgs
SystemButtonEventController = _ns_module.SystemButtonEventController
SystemFunctionButtonEventArgs = _ns_module.SystemFunctionButtonEventArgs
SystemFunctionLockChangedEventArgs = _ns_module.SystemFunctionLockChangedEventArgs
SystemFunctionLockIndicatorChangedEventArgs = _ns_module.SystemFunctionLockIndicatorChangedEventArgs
TappedEventArgs = _ns_module.TappedEventArgs
IPointerPointTransform = _ns_module.IPointerPointTransform



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum

import winsdk.system

_ns_module = winsdk.system._import_ns_module("Windows.ApplicationModel.Core")

try:
    import winsdk.windows.applicationmodel
except ImportError:
    pass

try:
    import winsdk.windows.applicationmodel.activation
except ImportError:
    pass

try:
    import winsdk.windows.foundation
except ImportError:
    pass

try:
    import winsdk.windows.foundation.collections
except ImportError:
    pass

try:
    import winsdk.windows.system
except ImportError:
    pass

try:
    import winsdk.windows.ui.core
except ImportError:
    pass

class AppRestartFailureReason(enum.IntEnum):
    RESTART_PENDING = 0
    NOT_IN_FOREGROUND = 1
    INVALID_USER = 2
    OTHER = 3

_ns_module._register_AppRestartFailureReason(AppRestartFailureReason)

AppListEntry = _ns_module.AppListEntry
CoreApplication = _ns_module.CoreApplication
CoreApplicationView = _ns_module.CoreApplicationView
CoreApplicationViewTitleBar = _ns_module.CoreApplicationViewTitleBar
HostedViewClosingEventArgs = _ns_module.HostedViewClosingEventArgs
UnhandledError = _ns_module.UnhandledError
UnhandledErrorDetectedEventArgs = _ns_module.UnhandledErrorDetectedEventArgs
ICoreApplicationUnhandledError = _ns_module.ICoreApplicationUnhandledError
IFrameworkView = _ns_module.IFrameworkView
IFrameworkViewSource = _ns_module.IFrameworkViewSource



# WARNING: Please don't edit this file. It was generated by Python/WinRT v1.0.0-beta.9

import enum
import datetime
import sys
import types
import typing

import winsdk.system
import winsdk.windows.foundation
import winsdk.windows.foundation.collections
import winsdk.windows.foundation.numerics
import winsdk.windows.graphics.directx.direct3d11
import winsdk.windows.media
import winsdk.windows.media.capture
import winsdk.windows.media.editing
import winsdk.windows.media.mediaproperties
import winsdk.windows.media.playback
import winsdk.windows.media.render
import winsdk.windows.media.transcoding
import winsdk.windows.storage.streams
import winsdk.windows.ui

class AudioEffectType(enum.IntEnum):
    OTHER = 0
    ACOUSTIC_ECHO_CANCELLATION = 1
    NOISE_SUPPRESSION = 2
    AUTOMATIC_GAIN_CONTROL = 3
    BEAM_FORMING = 4
    CONSTANT_TONE_REMOVAL = 5
    EQUALIZER = 6
    LOUDNESS_EQUALIZER = 7
    BASS_BOOST = 8
    VIRTUAL_SURROUND = 9
    VIRTUAL_HEADPHONES = 10
    SPEAKER_FILL = 11
    ROOM_CORRECTION = 12
    BASS_MANAGEMENT = 13
    ENVIRONMENTAL_EFFECTS = 14
    SPEAKER_PROTECTION = 15
    SPEAKER_COMPENSATION = 16
    DYNAMIC_RANGE_COMPRESSION = 17
    FAR_FIELD_BEAM_FORMING = 18
    DEEP_NOISE_SUPPRESSION = 19

class MediaEffectClosedReason(enum.IntEnum):
    DONE = 0
    UNKNOWN_ERROR = 1
    UNSUPPORTED_ENCODING_FORMAT = 2
    EFFECT_CURRENTLY_UNLOADED = 3

class MediaMemoryTypes(enum.IntEnum):
    GPU = 0
    CPU = 1
    GPU_AND_CPU = 2

Self = typing.TypeVar('Self')

class AudioCaptureEffectsManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioCaptureEffectsManager: ...
    def get_audio_capture_effects(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[AudioEffect]]: ...
    def add_audio_capture_effects_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AudioCaptureEffectsManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_audio_capture_effects_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class AudioEffect(winsdk.system.Object):
    audio_effect_type: AudioEffectType
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioEffect: ...

class AudioEffectDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioEffectDefinition: ...
    @typing.overload
    def __new__(cls: typing.Type[AudioEffectDefinition], activatable_class_id: str) -> AudioEffectDefinition:...
    @typing.overload
    def __new__(cls: typing.Type[AudioEffectDefinition], activatable_class_id: str, props: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> AudioEffectDefinition:...

class AudioEffectsManager(winsdk.system.Object):
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioEffectsManager: ...
    @typing.overload
    @staticmethod
    def create_audio_capture_effects_manager(device_id: str, category: winsdk.windows.media.capture.MediaCategory) -> typing.Optional[AudioCaptureEffectsManager]: ...
    @typing.overload
    @staticmethod
    def create_audio_capture_effects_manager(device_id: str, category: winsdk.windows.media.capture.MediaCategory, mode: winsdk.windows.media.AudioProcessing) -> typing.Optional[AudioCaptureEffectsManager]: ...
    @typing.overload
    @staticmethod
    def create_audio_render_effects_manager(device_id: str, category: winsdk.windows.media.render.AudioRenderCategory) -> typing.Optional[AudioRenderEffectsManager]: ...
    @typing.overload
    @staticmethod
    def create_audio_render_effects_manager(device_id: str, category: winsdk.windows.media.render.AudioRenderCategory, mode: winsdk.windows.media.AudioProcessing) -> typing.Optional[AudioRenderEffectsManager]: ...

class AudioRenderEffectsManager(winsdk.system.Object):
    effects_provider_settings_label: str
    effects_provider_thumbnail: typing.Optional[winsdk.windows.storage.streams.IRandomAccessStreamWithContentType]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> AudioRenderEffectsManager: ...
    def get_audio_render_effects(self) -> typing.Optional[winsdk.windows.foundation.collections.IVectorView[AudioEffect]]: ...
    def show_settings_u_i(self) -> None: ...
    def add_audio_render_effects_changed(self, handler: winsdk.windows.foundation.TypedEventHandler[AudioRenderEffectsManager, winsdk.system.Object]) -> winsdk.windows.foundation.EventRegistrationToken: ...
    def remove_audio_render_effects_changed(self, token: winsdk.windows.foundation.EventRegistrationToken) -> None: ...

class CompositeVideoFrameContext(winsdk.system.Object):
    background_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    output_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    surfaces_to_overlay: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> CompositeVideoFrameContext: ...
    def get_overlay_for_surface(self, surface_to_overlay: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DSurface]) -> typing.Optional[winsdk.windows.media.editing.MediaOverlay]: ...

class ProcessAudioFrameContext(winsdk.system.Object):
    input_frame: typing.Optional[winsdk.windows.media.AudioFrame]
    output_frame: typing.Optional[winsdk.windows.media.AudioFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ProcessAudioFrameContext: ...

class ProcessVideoFrameContext(winsdk.system.Object):
    input_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    output_frame: typing.Optional[winsdk.windows.media.VideoFrame]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> ProcessVideoFrameContext: ...

class SlowMotionEffectDefinition(winsdk.system.Object):
    time_stretch_rate: winsdk.system.Double
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> SlowMotionEffectDefinition: ...
    def __new__(cls: typing.Type[SlowMotionEffectDefinition]) -> SlowMotionEffectDefinition:...

class VideoCompositorDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoCompositorDefinition: ...
    @typing.overload
    def __new__(cls: typing.Type[VideoCompositorDefinition], activatable_class_id: str) -> VideoCompositorDefinition:...
    @typing.overload
    def __new__(cls: typing.Type[VideoCompositorDefinition], activatable_class_id: str, props: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> VideoCompositorDefinition:...

class VideoEffectDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoEffectDefinition: ...
    @typing.overload
    def __new__(cls: typing.Type[VideoEffectDefinition], activatable_class_id: str) -> VideoEffectDefinition:...
    @typing.overload
    def __new__(cls: typing.Type[VideoEffectDefinition], activatable_class_id: str, props: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> VideoEffectDefinition:...

class VideoTransformEffectDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    rotation: winsdk.windows.media.mediaproperties.MediaRotation
    processing_algorithm: winsdk.windows.media.transcoding.MediaVideoProcessingAlgorithm
    padding_color: winsdk.windows.ui.Color
    output_size: winsdk.windows.foundation.Size
    mirror: winsdk.windows.media.mediaproperties.MediaMirroringOptions
    crop_rectangle: winsdk.windows.foundation.Rect
    spherical_projection: typing.Optional[VideoTransformSphericalProjection]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoTransformEffectDefinition: ...
    def __new__(cls: typing.Type[VideoTransformEffectDefinition]) -> VideoTransformEffectDefinition:...

class VideoTransformSphericalProjection(winsdk.system.Object):
    view_orientation: winsdk.windows.foundation.numerics.Quaternion
    projection_mode: winsdk.windows.media.playback.SphericalVideoProjectionMode
    is_enabled: winsdk.system.Boolean
    horizontal_field_of_view_in_degrees: winsdk.system.Double
    frame_format: winsdk.windows.media.mediaproperties.SphericalVideoFrameFormat
    @staticmethod
    def _from(obj: winsdk.system.Object) -> VideoTransformSphericalProjection: ...

class IAudioEffectDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IAudioEffectDefinition: ...

class IBasicAudioEffect(winsdk.system.Object):
    supported_encoding_properties: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.mediaproperties.AudioEncodingProperties]]
    use_input_frame_for_output: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IBasicAudioEffect: ...
    def close(self, reason: MediaEffectClosedReason) -> None: ...
    def discard_queued_frames(self) -> None: ...
    def process_frame(self, context: typing.Optional[ProcessAudioFrameContext]) -> None: ...
    def set_encoding_properties(self, encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.AudioEncodingProperties]) -> None: ...
    def set_properties(self, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...

class IBasicVideoEffect(winsdk.system.Object):
    is_read_only: winsdk.system.Boolean
    supported_encoding_properties: typing.Optional[winsdk.windows.foundation.collections.IVectorView[winsdk.windows.media.mediaproperties.VideoEncodingProperties]]
    supported_memory_types: MediaMemoryTypes
    time_independent: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IBasicVideoEffect: ...
    def close(self, reason: MediaEffectClosedReason) -> None: ...
    def discard_queued_frames(self) -> None: ...
    def process_frame(self, context: typing.Optional[ProcessVideoFrameContext]) -> None: ...
    def set_encoding_properties(self, encoding_properties: typing.Optional[winsdk.windows.media.mediaproperties.VideoEncodingProperties], device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]) -> None: ...
    def set_properties(self, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...

class IVideoCompositor(winsdk.system.Object):
    time_independent: winsdk.system.Boolean
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVideoCompositor: ...
    def close(self, reason: MediaEffectClosedReason) -> None: ...
    def composite_frame(self, context: typing.Optional[CompositeVideoFrameContext]) -> None: ...
    def discard_queued_frames(self) -> None: ...
    def set_encoding_properties(self, background_properties: typing.Optional[winsdk.windows.media.mediaproperties.VideoEncodingProperties], device: typing.Optional[winsdk.windows.graphics.directx.direct3d11.IDirect3DDevice]) -> None: ...
    def set_properties(self, configuration: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]) -> None: ...

class IVideoCompositorDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVideoCompositorDefinition: ...

class IVideoEffectDefinition(winsdk.system.Object):
    activatable_class_id: str
    properties: typing.Optional[winsdk.windows.foundation.collections.IPropertySet]
    @staticmethod
    def _from(obj: winsdk.system.Object) -> IVideoEffectDefinition: ...

